"""
Main code
"""

import random
import string
from datetime import datetime
from typing import Optional

from slinky import db


def random_string(length: int = 4) -> str:
    """
    Create a random, alphanumeric string of the length specified

    Args:
        length (int, optional): length of string to generate. Defaults to 4.

    Returns:
        str: random alphanumeric string
    """
    allowed_chars: str = string.ascii_letters + string.digits

    return ''.join(random.SystemRandom().choice(allowed_chars) for _ in range(length))


def add_shortcode(
    url: str,
    length: int = 4,
    fixed_views: int = 0,
    expiry: datetime = datetime.max,
) -> str:
    """
    Add a shortcode to the DB

    Args:
        url (str): URL to redirect to
        fixed_views (int, optional): number of views to serve before expiring.
            Defaults to 0 (no limit).
        expiry (int, optional): date of expiry. Defaults to 0 (no limit).

    Returns:
        str: shortcode for the redirect
    """
    session = db.session()
    shortcode = random_string(length=length)
    dbentry = db.ShortURL(
        shortcode=shortcode,
        url=url,
        fixed_views=fixed_views,
        expiry=expiry,
    )
    session.add(dbentry)
    session.commit()
    session.close()

    return shortcode
