"""
DB component
"""
from sqlalchemy import Column, Integer, String, create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import Session, sessionmaker

Base = declarative_base()


class ShortURL(Base):  # pylint: disable=too-few-public-methods
    """
    Class to describe the DB schema for ShortURLs
    """

    __tablename__ = 'shorturl'

    id = Column(Integer, primary_key=True)
    shortcode = Column(String(128), unique=True, nullable=False)
    url = Column(String(2048), unique=False, nullable=False)
    fixed_views = Column(Integer, unique=False, nullable=False)
    expiry = Column(Integer, unique=False, nullable=False)


def session() -> Session:
    """
    Create a DB session

    Returns:
        Session: the DB session object
    """
    engine = create_engine('sqlite:////tmp/test.db')
    Base.metadata.create_all(engine)
    new_session = sessionmaker(bind=engine)
    return new_session()
